hessenberg_in_place

Function hessenberg_in_place 

pub fn hessenberg_in_place<T: ComplexField>(
    A: MatMut<'_, T>,
    householder: MatMut<'_, T>,
    par: Par,
    stack: &mut MemStack,
    params: Spec<HessenbergParams, T>,
)
computes a matrix $A$’s hessenberg decomposition such that $A = Q H Q^H$

$H$ is a hessenberg matrix stored in the upper triangular half of $A$ (plus the subdiagonal)

$Q$ is a sequence of householder reflections stored in the unit lower triangular half of $A$ (excluding the diagonal), with the householder coefficients being stored in householder